#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (C) 2009 Pâris Quentin
# Copyright (C) 2007-2010 PlayOnLinux Team

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

import os, sys, string, shutil
import wx, time
#from subprocess import Popen,PIPE

import wine_versions
import lib.playonlinux as playonlinux
import lib.wine as wine
import lib.Variables as Variables
import lib.lng as lng
import lib.irc as irc
from wx.lib.ClickableHtmlWindow import PyClickableHtmlWindow

class Onglets(wx.Notebook):
    # Classe dérivée du wx.Notebook
    def __init__(self, parent):
        self.notebook = wx.Notebook.__init__(self, parent, -1)

    def getSettings(self): # Faudra revoir ça dans une future version
        irc_settings = {}

        if(os.environ["POL_OS"] == "Linux"):
            irc_settings['NICKNAME'] = os.environ["USER"]+"-pol"
        else:
            irc_settings['NICKNAME'] = os.environ["USER"]+"-pom"

        irc_settings['AUTOCONNECT'] = "0"
        irc_settings['ALERT'] = "0"
        irc_settings["PLAYSOUND"] = "1"
        if(os.path.exists(Variables.playonlinux_rep+"/configurations/options/irc")):
            ircfile = open(Variables.playonlinux_rep+"/configurations/options/irc","r").readlines()
            self.i = 0

            while(self.i < len(ircfile)):
                line_parsed = string.split(ircfile[self.i].replace("\n","").replace("\r",""),"=")
                irc_settings[line_parsed[0]] = line_parsed[1]
                self.i += 1
        return irc_settings

    def selectChanByText(self, text):
        self.item = self.root_window

        self.ij = 0
        self.texte = None
        while(self.texte != text):
            if(self.ij >= len(irc.chans)):
                return self.window.GetLastChild(self.root_window)

            self.item = self.window.GetNextVisible(self.item)
            self.texte = self.window.GetItemText(self.item)
            self.ij += 1


        return self.item

    def OpenWindow(self):
        #if(nom.lower() not in irc.chans and not "@" in nom and nom != "freenode-connect"):
        #self.old_selection = self.window.GetItemText(self.window.GetSelection())
        self.window.DeleteAllItems()
        self.root_window = self.window.AddRoot("")
        self.i = 0
        while(self.i < len(irc.chans)):
            nom = irc.chans[self.i].lower()
            if("." not in nom and nom != "freenode-connect"):
                if("#" in nom):
                    self.window.AppendItem(self.root_window, nom, 0)
                else:
                    if(nom.lower() == "nickserv" or nom.lower() == "chanserv" or nom.lower() == "botserv"):
                        self.window.AppendItem(self.root_window, nom, 2)
                    else:
                        if(nom.lower() == "playonlinux"):
                            self.window.AppendItem(self.root_window, nom, 3)
                        else:
                            self.window.AppendItem(self.root_window, nom, 1)
                #if(self.i == 0):
                    #self.window.SelectItem(self.window.GetLastChild(self.root_window))
            self.i += 1
        #item = self.selectChanByText(self.old_selection)
        #self.window.SelectItem(item)
            #irc.open_window.append(nom.lower())

    def selectWindow(self, name):
        item = self.selectChanByText(name)
        self.window.SelectItem(item)

    def AjouteIRC(self, nom):
        self.panel = wx.Panel(self, -1)
        self.panels_button = wx.Panel(self.panel, -1)
        self.panels_main = wx.Panel(self.panel, -1)
        self.panels_connexion = wx.Panel(self.panel, -1)
        #self.content =  wx.TextCtrl(self.panel, 107, pos=(0,20), size=(500,300), style = wx.TE_MULTILINE | wx.TE_RICH2 | wx.CB_READONLY | wx.RAISED_BORDER)

        self.content = PyClickableHtmlWindow(self.panels_main, -1, style=wx.RAISED_BORDER)
        self.buddy = wx.TreeCtrl(self.panels_main, 126, style=wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT|wx.RAISED_BORDER)
        self.buddy.SetSpacing(0);

        self.window = wx.TreeCtrl(self.panels_main, 127, style=wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT|wx.RAISED_BORDER)
        #self.root_window = self.window.AddRoot("")
        self.window.SetSpacing(0);

        self.buddy_images = wx.ImageList(16, 16)
        self.buddy_images.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/install/star.png"));
        self.buddy_images.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/install/h-star.png"));
        self.buddy_images.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/playonlinux16.png"));
        self.buddy_images.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/install/spacer16.png"));
        self.buddy_images.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/install/star.png"));
        self.buddy.SetImageList(self.buddy_images)

        self.window_images = wx.ImageList(16,16)
        self.window_images.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/internet-group-chat.png"));
        self.window_images.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/system-users.png"));
        self.window_images.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/applications-system.png"));
        self.window_images.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/playonlinux16.png"));
        self.window.SetImageList(self.window_images)

        self.buddy.SetSpacing(0);
        self.field =  wx.TextCtrl(self.panels_button, 121, style = wx.TE_MULTILINE)
        self.button = wx.Button(self.panels_button, 122, _("Send"))
        self.connect = wx.Button(self.panels_connexion, 123, _("Connect"), pos=(0,0), size=(150,28))
        self.disconnect = wx.Button(self.panels_connexion, 124, _("Disconnect"), pos=(0,0), size=(150,28))
        self.close = wx.Button(self.panels_connexion, 128, _("Leave"), pos=(155,0), size=(150,28))
        #self.close = wx.BitmapButton(self.panels_connexion, 128, wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/wineserver.png"), pos=(630,0))
        self.settings = self.getSettings()
        self.nickname = wx.TextCtrl(self.panels_connexion, 125, self.settings["NICKNAME"], size=(300,25), pos=(330,2))
        #self.channel_choices = ["#playonlinux-fr","#playonlinux-en","#playonlinux-it","#playonlinux-ru","#playonlinux-pl","#playonlinux-hu","#playonlinux-es"]
        #self.channel_choices.sort()
        #self.channel = wx.ComboBox(self.panels_connexion, 130,  _("Join a channel"), size=(190,28), pos=(510,0), choices=self.channel_choices)
        self.close.Enable(False)
        self.sizer = wx.BoxSizer(wx.VERTICAL)
        self.sizerInputs = wx.BoxSizer(wx.HORIZONTAL)
        self.sizerMain = wx.BoxSizer(wx.HORIZONTAL)

        self.sizer.Add(self.panels_connexion, 3, wx.EXPAND|wx.ALL, 2)
        self.sizer.Add(self.panels_main, 36, wx.EXPAND|wx.ALL, 2)
        self.sizer.Add(self.panels_button, 4, wx.EXPAND|wx.ALL, 2)

        self.sizerInputs.Add(self.field, 14, wx.EXPAND|wx.ALL, 2)
        self.sizerInputs.Add(self.button, 4, wx.EXPAND|wx.ALL, 2)

        self.sizerMain.Add(self.window, 4, wx.EXPAND|wx.ALL, 2)
        self.sizerMain.Add(self.content, 10, wx.EXPAND|wx.ALL, 2)
        self.sizerMain.Add(self.buddy, 4, wx.EXPAND|wx.ALL, 2)

        self.panel.SetSizer(self.sizer)
        self.panels_button.SetSizer(self.sizerInputs)
        self.panels_main.SetSizer(self.sizerMain)
        self.panel.SetAutoLayout(True)

        self.AddPage(self.panel, nom)
        self.field.Bind(wx.EVT_KEY_UP, self.EventKey)
        self.nickname.Bind(wx.EVT_KEY_UP, self.NicknameKey)
        #self.channel.Bind(wx.EVT_KEY_UP, self.EventChannel)

        wx.EVT_COMBOBOX(self, 130, self.JoinChan)
        wx.EVT_BUTTON(self,  122,  self.EventButton)
        wx.EVT_BUTTON(self,  123,  self.EventStart)
        wx.EVT_BUTTON(self,  124,  self.EventStop)
        wx.EVT_BUTTON(self,  128,  self.EventClose)
        wx.EVT_TREE_ITEM_ACTIVATED(self, 126, self.AddNick)
        #wx.EVT_TREE_ITEM_ACTIVATED(self, 127, self.filtrer)
        #self.disconnect.Enable(False)
        #self.EventStart(self)

    def AddNick(self, event):
        self.buddy_txt = self.buddy.GetItemText(self.buddy.GetSelection()).encode("utf-8","replace")
        irc.join(self.buddy_txt)
        #if(self.buddy_txt not in irc.chans):

        #self.field.SetValue("/msg "+self.buddy_txt+" ")
        #self.OpenWindow(self.buddy_txt)

    def SendMessage(self):
        self.chars = self.field.GetValue().replace('\n','').encode("utf-8","replace")
        if(self.chars):
            self.field.Clear()
            irc.SendMSG(self.chars)
        else:
            self.field.Clear()

    def EventClose(self, event):
        #index = irc.get_index(self.window.GetItemText(self.window.GetSelection()).lower()):
        #print index

        #del irc.messages[index]
        #del irc.names[index]
        #del irc.endnames[index]
        #del irc.chans[index]
        irc.leave_chan(self.window.GetItemText(self.window.GetSelection()).lower())

        self.window.Delete(self.window.GetSelection())
        #self.close.Enable(False)

    def EventStart(self, event):
        irc.Nick = self.nickname.GetValue().encode("utf-8","replace")
        irc.Connexion()

    def EventChannel(self, event):
        if(event.GetKeyCode() == wx.WXK_RETURN):
            self.JoinChan(self)

        event.Skip()

    def JoinChan(self, event):
        my_chan = self.channel.GetValue()
        if(my_chan[0] == "#"):
            if(irc.ircconnected == True):
                irc.join(my_chan)
        self.channel.SetValue(_("Join a channel"))
    def EventStop(self, event):
        irc.stop()

    def EventButton(self, event):
        self.SendMessage()

    def EventKey(self, event):
        if(event.GetKeyCode() == wx.WXK_RETURN):
            self.SendMessage()

        event.Skip()

    def NicknameKey(self, event):
        if(event.GetKeyCode() == wx.WXK_RETURN):
            if(irc.ircconnected == True):
                irc.ChangeNick(self.nickname.GetValue().encode("utf-8","replace"))
            else:
                irc.Connexion()
        event.Skip()


class IrcClient(wx.Frame):
    def __init__(self,parent,title=""):
        wx.Frame.__init__(self, parent, -1, title, size = (700, 500))

        self.SetIcon(wx.Icon(Variables.playonlinux_env+"/etc/playonlinux.png", wx.BITMAP_TYPE_ANY))
        self.timer = wx.Timer(self, 1)
        self.onglets = Onglets(self)
        #self.onglets.hide()
        self.onglets.AjouteIRC(_("Messenger"))
        self.oldreload = ""
        self.oldimg = ""
        self.names = ["~"]
        self.messages = ["~"]
        self.chans = ["~"]
        self.already_connected = False
        self.settings = irc.getSettings()
        self.resized = False
        #self.settings["AUTOCONNECT"] = "TRUE"
        #Timer, regarde toute les secondes si il faut actualiser la liste
        self.Bind(wx.EVT_TIMER, self.AutoReload, self.timer)
        wx.EVT_CLOSE(self, self.CloseIRC)
        self.timer.Start(200)

    def CloseIRC(self, event):
        if(not irc.ircconnected or wx.YES == wx.MessageBox(_('If you close this window, you cannot read further replies. Are you sure that you want to close it?').format(os.environ["APPLICATION_TITLE"]).decode("utf-8","replace"), os.environ["APPLICATION_TITLE"] ,style=wx.YES_NO | wx.ICON_QUESTION)):
            self.onglets.EventStop(self)
            self.Destroy()

    def change_irc_window(self, event):
        #self.irc_user_list(self)
        self.html_reload(self)
        #print self.onglets.window.GetItemText(self.onglets.window.GetSelection())

    def irc_key(self, item):
        if(item[0] == "~"):
            return ("A")
        else:
            if(item[0] == "@" or item[0] == "&"):
                return ("B")
            else :
                if(item[0] == "%"):
                    return ("C")
                else:
                    if(item[0] == "+"):
                        return ("D")
                    else:
                        return string.lower(item[0])

    def html_reload(self, event):
                #print("Refresh html")
        self.window_txt = self.onglets.window.GetItemText(self.onglets.window.GetSelection()).encode("utf-8","replace")
        irc.selected_window = self.window_txt
        self.chat_content = ""
        # On regarde quelle liste on va prendre
        id_liste = irc.get_index(self.window_txt)
        # On ajoute tout
        self.i = 0
        if(len(irc.messages[id_liste]) >= 300):
            del irc.messages[id_liste][0]

        while(self.i < len(irc.messages[id_liste])):
            if(self.i != 0):
                self.chat_content += "\n<br />"
            self.chat_content += irc.messages[id_liste][self.i]
            self.i += 1
        self.onglets.content.SetPage("<html><head></head><body><p align='left'>"+self.chat_content+"</p></body></html>")
        self.onglets.content.Scroll(0,len(irc.messages[id_liste])*2)

    def html_reload_status(self, event):
        self.chat_content = ""
        # On regarde quelle liste on va prendre
        self.i = 0
        if(len(irc.status_messages) >= 300):
            del irc.status_messages[0]

        while(self.i < len(irc.status_messages)):
            self.chat_content += irc.status_messages[self.i]+"<br />\n"
            self.i += 1
        self.onglets.content.SetPage("<html><head></head><body><p align='left'>"+self.chat_content+"</p></body></html>")
        self.onglets.content.Scroll(0,len(irc.status_messages)*2)

    def irc_user_list(self, event):
        self.window_txt = self.onglets.window.GetItemText(self.onglets.window.GetSelection()).encode("utf-8","replace").lower()

        irc.selected_window = self.window_txt
        # On casse tout
        self.onglets.buddy.DeleteAllItems()
        self.buddy_root = self.onglets.buddy.AddRoot("")
        # On regarde quelle liste on va prendre
        id_liste = irc.get_index(self.window_txt)
        # On ajoute tout
        self.user_i = 0
        while(self.user_i < len(irc.names[id_liste])):
            num = 3
            irc.names[id_liste].sort(key=self.irc_key)
            if("@" in irc.names[id_liste][self.user_i] or "&" in irc.names[id_liste][self.user_i]):
                num = 0
            if("~" in irc.names[id_liste][self.user_i]):
                num = 4
            if("%" in irc.names[id_liste][self.user_i]):
                num = 1
            if("+" in irc.names[id_liste][self.user_i]):
                num = 2
            self.onglets.buddy.AppendItem(self.buddy_root, irc.names[id_liste][self.user_i].replace("&","").replace("~","").replace("%","").replace("+","").replace("@",""), num)
            html_hex = irc.GenColor(irc.names[id_liste][self.user_i].replace("&","").replace("~","").replace("%","").replace("+","").replace("@",""))
            self.couleur = [pow(int(html_hex[2],16),2),pow(int(html_hex[3],16),2),pow(int(html_hex[4],16),2)]
            self.onglets.buddy.SetItemTextColour(self.onglets.buddy.GetLastChild(self.buddy_root), wx.Colour(int(self.couleur[0]),int(self.couleur[1]),int(self.couleur[2])))
            self.user_i += 1
        #wx.Yield()

    def AutoReload(self, event):
        if(self.resized == False): # wx 2.9 resizing probem
            self.SetSize((800,500))
            self.resized = True

        self.new_string = irc.string_to_write
        if(irc.ircconnected == True):
            if(self.chans != irc.chans):
                self.onglets.OpenWindow()
                self.chans = irc.chans[:]
                #print "Refresh"
            #else :
            #print str(self.chans)+" --- "+str(irc.chans)

            self.window_txt = self.onglets.window.GetItemText(self.onglets.window.GetSelection()).encode("utf-8","replace").lower()

            if(len(self.window_txt) > 0):
                id_liste = irc.get_index(self.window_txt)
                if(self.window_txt[0] == "#"):
                #print self.names
                    if(irc.names[id_liste] != self.names):
                        self.irc_user_list(self)
                        self.names = irc.names[id_liste][:]

            #if(len(irc.messages) > id_liste+1):

                if(irc.messages[id_liste] != self.messages):
                    self.html_reload(self)
                    self.messages = irc.messages[id_liste][:]

            if(irc.select_window != ""):
                self.onglets.selectWindow(irc.select_window)
                irc.select_window = ""

            if(self.onglets.window.GetItemText(self.onglets.window.GetSelection()) != irc.selected_window):
                irc.selected_window = self.onglets.window.GetItemText(self.onglets.window.GetSelection())

            if(irc.selected_window == "#playonlinux" or irc.selected_window == ""):
                self.onglets.close.Enable(False)
            else:
                self.onglets.close.Enable(True)


            self.onglets.connect.Hide()
            self.onglets.disconnect.Show()
            if(len(self.chans) == 0):
                if(irc.status_messages != self.messages):
                    self.html_reload_status(self)
                    self.messages = irc.status_messages[:]
        else:
            if(irc.status_messages != self.messages):
                self.html_reload_status(self)
                self.messages = irc.status_messages[:]

            self.onglets.buddy.DeleteAllItems()
            self.onglets.window.DeleteAllItems()
            self.onglets.connect.Show()
            self.onglets.disconnect.Hide()
            if(self.settings["AUTOCONNECT"] == "1"):
                if(self.already_connected == False):
                    irc.Nick = self.onglets.nickname.GetValue().encode("utf-8","replace")
                    irc.connect()
                    self.already_connected = True;





irc = irc.IRCClient()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (C) 2009 Pâris Quentin
# Copyright (C) 2007-2010 PlayOnLinux Team

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

from asyncore import dispatcher
import wxversion, os, getopt, sys, urllib, signal, socket, string
import wx, time, re
import webbrowser, shutil
import threading, time, codecs
from select import select
#from subprocess import Popen,PIPE

import lib.Variables as Variables
import lib.lng as lng
import lib.playonlinux as playonlinux

class getPlugins(threading.Thread):
    def __init__(self):
        threading.Thread.__init__(self)
        self.thread_message = "#WAIT#"
        self.versions = []
        self.start()

    def download(self, game):
        self.getDescription = game

    def run(self):
        self.thread_running = True
        while(self.thread_running):
            if(self.thread_message == "get"):
                try :
                    url = 'http://mulx.playonlinux.com/wine/linux-i386/LIST'
                    req = urllib2.Request(url)
                    handle = urllib2.urlopen(req)
                    time.sleep(1)
                    available_versions = handle.read()
                    available_versions = string.split(available_versions,"\n")
                    self.i = 0
                    self.versions_ = []
                    while(self.i < len(available_versions) - 1):
                        informations = string.split(available_versions[self.i], ";")
                        version = informations[1]
                        package = informations[0]
                        sha1sum = informations[2]
                        if(not os.path.exists(Variables.playonlinux_rep+"/WineVersions/"+version)):
                            self.versions_.append(version)
                        self.i += 1
                    self.versions_.reverse()
                    self.versions = self.versions_[:]

                    self.thread_message = "Ok"
                except :
                    time.sleep(1)
                    self.thread_message = "Err"
                    self.versions = ["Wine packages website is unavailable"]
            else:
                time.sleep(0.2)


class Onglets(wx.Notebook):
        # Classe dérivée du wx.Notebook
    def __init__(self, parent):
        if(os.environ["POL_OS"] == "Mac"):
            self.fontTitle = wx.Font(14, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_BOLD, False, "", wx.FONTENCODING_DEFAULT)
            self.caption_font = wx.Font(11, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL,False, "", wx.FONTENCODING_DEFAULT)
        else :
            self.fontTitle = wx.Font(12, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_BOLD, False, "", wx.FONTENCODING_DEFAULT)
            self.caption_font = wx.Font(8, wx.FONTFAMILY_DEFAULT, wx.FONTSTYLE_NORMAL, wx.FONTWEIGHT_NORMAL,False, "", wx.FONTENCODING_DEFAULT)


        self.notebook = wx.Notebook.__init__(self, parent, -1)
        self.images_onglets = wx.ImageList(16, 16)
        self.images_onglets.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/input-gaming.png"));
        self.images_onglets.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/internet-group-chat.png"));
        self.images_onglets.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/internet-web-browser.png"));
        self.images_onglets.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/user-desktop.png"));
        self.images_onglets.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/application-x-executable.png"));
        self.images_onglets.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/package-x-generic.png"));
        self.images_onglets.Add(wx.Bitmap(Variables.playonlinux_env+"/resources/images/menu/extensions.png"));

        self.SetImageList(self.images_onglets)


    def browser_test(self, event):
        if(self.Navigator.GetValue() == "Default"):
            webbrowser.open("http://www.playonlinux.com")
        else:
            os.system(self.Navigator.GetValue()+" http://www.playonlinux.com &")

    def term_test(self, event):
        os.system("bash "+Variables.playonlinux_env+"/bash/terminals/"+self.Term.GetValue()+" sleep 2 &")

    def Internet(self, nom):
        self.panelInternet = wx.Panel(self, -1)

        if(os.path.exists(Variables.playonlinux_rep+"/configurations/options/offline")):
            if(open(Variables.playonlinux_rep+"/configurations/options/offline",'r').read() == '1'):
                self.OffLineCheck.SetValue(1)

        self.ProxySettings = wx.StaticText(self.panelInternet, -1, _("Proxy configuration"), (0,0), wx.DefaultSize)
        self.ProxySettings.SetFont(self.fontTitle)

        proxy_settings = {}

        proxy_settings['PROXY_ENABLED'] = playonlinux.GetSettings("PROXY_ENABLED")
        if(proxy_settings['PROXY_ENABLED'] == ""):
            proxy_settings['PROXY_ENABLED'] = "0"
        proxy_settings['PROXY_ADRESS'] = playonlinux.GetSettings("PROXY_URL")
        proxy_settings["PROXY_PORT"] = playonlinux.GetSettings("PROXY_PORT")
        proxy_settings["PROXY_LOGIN"] = playonlinux.GetSettings("PROXY_LOGIN")
        proxy_settings["PROXY_PASS"] = playonlinux.GetSettings("PROXY_PASSWORD")

        self.ProxyCheck = wx.CheckBox(self.panelInternet, 120, _("Set a proxy"),pos=(10,30))
        self.ProxyCheck.SetValue(int(proxy_settings['PROXY_ENABLED']))

        self.ProxyTxtAdresse = wx.StaticText(self.panelInternet, -1, _("Proxy address"), (10,60), wx.DefaultSize)
        self.ProxyAdresse = wx.TextCtrl(self.panelInternet, -1, proxy_settings["PROXY_ADRESS"], pos=(20,80),size=(300,27))

        self.ProxyTxtPort = wx.StaticText(self.panelInternet, -1, _("Proxy port"), (10,120), wx.DefaultSize)
        self.ProxyPort = wx.TextCtrl(self.panelInternet, -1, proxy_settings["PROXY_PORT"], pos=(20,140),size=(80,27))

        self.ProxyTxtLogin = wx.StaticText(self.panelInternet, -1, _("Proxy login"), (10,180), wx.DefaultSize)
        self.ProxyLogin = wx.TextCtrl(self.panelInternet, -1, proxy_settings["PROXY_LOGIN"], pos=(20,200),size=(300,27))

        self.ProxyTxtPass = wx.StaticText(self.panelInternet, -1, _("Proxy password"), (10,240), wx.DefaultSize)
        self.ProxyPass = wx.TextCtrl(self.panelInternet, -1, proxy_settings["PROXY_PASS"], pos=(20,260),size=(300,27), style=wx.TE_PASSWORD)
        self.AddPage(self.panelInternet, nom, imageId=2)
        wx.EVT_CHECKBOX(self, 120, self.proxy_enable)
        self.proxy_enable(self)

    def proxy_enable(self, event):
        if(self.ProxyCheck.IsChecked() == 1):
            self.ProxyAdresse.Enable(True)
            self.ProxyLogin.Enable(True)
            self.ProxyPass.Enable(True)
            self.ProxyPort.Enable(True)
        else:
            self.ProxyAdresse.Enable(False)
            self.ProxyLogin.Enable(False)
            self.ProxyPass.Enable(False)
            self.ProxyPort.Enable(False)



    def LoadPlugins(self):
        self.pluginlist.DeleteAllItems()
        self.pluginImgList.RemoveAll()
        plugins=os.listdir(Variables.playonlinux_rep+"/plugins/")
        self.i = 0

        PluginsRoot = self.pluginlist.AddRoot("")
        plugins.sort()
        while(self.i < len(plugins)):
            self.pluginlist.AppendItem(PluginsRoot, plugins[self.i], self.i)
            if(os.path.exists(Variables.playonlinux_rep+"/plugins/"+plugins[self.i]+"/enabled") == False):
                self.pluginlist.SetItemTextColour(self.pluginlist.GetLastChild(PluginsRoot), wx.Colour(150,150,150))
            self.icon_look_for = Variables.playonlinux_rep+"/plugins/"+plugins[self.i]+"/icon"
            if(os.path.exists(self.icon_look_for)):
                self.pluginImgList.Add(wx.Bitmap(self.icon_look_for))
            else:
                self.pluginImgList.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/playonlinux16.png"))
            self.i += 1
        self.EnablePlugin.Enable(False)
        self.ConfigurePlugin.Enable(False)
        self.DelPlugin.Enable(False)

    def Plugins(self, nom):
        self.panelPlugins= wx.Panel(self, -1)
        self.panels_buttons_plugins = wx.Panel(self.panelPlugins, -1)

        self.sizerPlugins = wx.BoxSizer(wx.VERTICAL)
        self.txtPlugin = wx.StaticText(self.panelPlugins, -1, _("Installed plugins"), size=wx.DefaultSize)
        self.txtPlugin.SetFont(self.fontTitle)
        self.pluginlist = wx.TreeCtrl(self.panelPlugins, 220, style=Variables.widget_borders|wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT)
        self.pluginlist.SetSpacing(0)

        self.pluginImgList = wx.ImageList(16,16)

        self.pluginlist.SetImageList(self.pluginImgList)



        self.sizerPlugins.Add(self.txtPlugin, 1, wx.EXPAND|wx.ALL, 2)
        self.sizerPlugins.Add(self.pluginlist, 7, wx.EXPAND|wx.ALL, 2)

        self.sizerPlugins.Add(self.panels_buttons_plugins, 6, wx.EXPAND|wx.ALL, 2)

        self.panelPlugins.SetSizer(self.sizerPlugins)
        self.panelPlugins.SetAutoLayout(True)
        self.AddPlugin = wx.Button(self.panels_buttons_plugins, wx.ID_ADD, _("Add"), pos=(0,0), size=(100,35))
        self.DelPlugin = wx.Button(self.panels_buttons_plugins, wx.ID_REMOVE, _("Remove"), pos=(100,0), size=(100,35))
        self.ConfigurePlugin = wx.Button(self.panels_buttons_plugins, 212, _("Configure"), pos=(0,38), size=(100,35))
        self.EnablePlugin = wx.Button(self.panels_buttons_plugins, 213, _("Enable"), pos=(100,38), size=(100,35))
        self.txtPlugin = wx.StaticText(self.panels_buttons_plugins, -1, _("Choose a plugin"), size=(300,150), pos=(200,5))

        self.LoadPlugins()

        self.AddPage(self.panelPlugins, nom, imageId=5)

        wx.EVT_TREE_SEL_CHANGED(self, 220, self.choose_plugin)

        wx.EVT_BUTTON(self, 214, self.disable)
        wx.EVT_BUTTON(self, 213, self.enable)
        wx.EVT_BUTTON(self, 212, self.setup_plug)
        wx.EVT_BUTTON(self, wx.ID_REMOVE, self.delete_plug)
        wx.EVT_BUTTON(self, wx.ID_ADD, self.add_plug)

    def generateExts(self):
        self.list_ext.DeleteAllItems()
        i = 0
        self.exts = open(os.environ["POL_USER_ROOT"]+"/extensions.cfg").readlines()
        self.exts.sort()
        for line in self.exts:
            line = line.replace("\n","")
            line = string.split(line,"=")
            liner = "Line %s" % i
            self.list_ext.InsertStringItem(i, liner)
            self.list_ext.SetStringItem(i, 0, line[0])
            self.list_ext.SetStringItem(i, 1, line[1])
            i += 1
        self.app_installed_text.Hide()
        self.app_installed.Hide()
        self.delete_ext.Hide()
        self.app_installed.SetValue("")
        self.app_selected = -1

    def reditExt(self, event):

        playonlinux.SetSettings(self.ext_selected, self.app_installed.GetValue(),'_EXT_')
        self.generateExts()

    def editExt(self, event):
        self.app_installed_text.Show()
        self.app_installed.Show()
        self.delete_ext.Show()

        self.app_selected = string.split(self.exts[event.m_itemIndex],"=")[1]
        self.ext_selected = string.split(self.exts[event.m_itemIndex],"=")[0]

        self.app_installed.SetValue(self.app_selected.replace("\n","").replace("\r",""))

    def delExt(self, event):
        playonlinux.DeleteSettings(self.ext_selected,'_EXT_')
        self.generateExts()

    def newExt(self, event):
        newext = wx.GetTextFromUser(_("What is the extension?"), os.environ["APPLICATION_TITLE"])
        re.sub(r'\W+', '', newext)
        playonlinux.SetSettings(newext, "",'_EXT_')

        self.generateExts()

    def Extensions(self, nom):
        self.panelExt= wx.Panel(self, -1)
        self.list_ext = wx.ListCtrl(self.panelExt, 500, size=(504,350), pos=(1,1), style=wx.LC_REPORT)
        self.list_ext.InsertColumn(0, 'Extension')
        self.list_ext.InsertColumn(1, 'Program associated', width=320)

        self.app_installed_text = wx.StaticText(self.panelExt, pos=(1,388), label=_("Assigned program"))
        self.app_installed = wx.ComboBox(self.panelExt, 501, pos=(170,385),size=(200,25))
        self.delete_ext = wx.Button(self.panelExt, 502, pos=(372,385+2*Variables.windows_add_playonmac), size=(100,25), label=_("Delete"))


        self.add_ext = wx.Button(self.panelExt, 503, pos=(1,359), size=(100,25), label=_("New"))


        self.app_installed_list = os.listdir(os.environ["POL_USER_ROOT"]+"/shortcuts/")
        for i in self.app_installed_list:
            self.app_installed.Append(i)

        self.generateExts()
        self.AddPage(self.panelExt, nom, imageId=6)
        wx.EVT_LIST_ITEM_SELECTED(self, 500, self.editExt)
        wx.EVT_COMBOBOX(self, 501, self.reditExt)
        wx.EVT_BUTTON(self, 502, self.delExt)
        wx.EVT_BUTTON(self, 503, self.newExt)

    def setup_plug(self, event):
        self.current_plugin = self.pluginlist.GetItemText(self.pluginlist.GetSelection())
        self.plugin_path = Variables.playonlinux_rep+"/plugins/"+self.current_plugin
        os.system("bash \""+self.plugin_path+"/scripts/options\" &")

    def add_plug(self, event):
        self.FileDialog = wx.FileDialog(self)
        self.FileDialog.SetDirectory("~")
        self.FileDialog.SetWildcard("POL Packages (*.pol)|*.pol")
        result = self.FileDialog.ShowModal()
        if(result == wx.ID_OK and self.FileDialog.GetPath() != ""):
            if(wx.YES == wx.MessageBox(_("Are you sure you want to install: ").decode("utf-8","replace")+self.FileDialog.GetPath()+"?",os.environ["APPLICATION_TITLE"] ,style=wx.YES_NO | wx.ICON_QUESTION)):
                os.system("bash \""+Variables.playonlinux_env+"/playonlinux-pkg\" -i \""+self.FileDialog.GetPath().encode("utf-8","replace")+"\"")
                self.LoadPlugins()
        self.FileDialog.Destroy()

    def delete_plug(self, event):
        self.current_plugin = self.pluginlist.GetItemText(self.pluginlist.GetSelection())
        self.plugin_path = Variables.playonlinux_rep+"/plugins/"+self.current_plugin
        if(wx.YES == wx.MessageBox(_("Are you sure you want to delete: ").decode("utf-8","replace")+self.current_plugin+"?", os.environ["APPLICATION_TITLE"],style=wx.YES_NO | wx.ICON_QUESTION)):
            shutil.rmtree(self.plugin_path)
            self.LoadPlugins()
    def disable(self, event):
        self.current_plugin = self.pluginlist.GetItemText(self.pluginlist.GetSelection())
        self.plugin_path = Variables.playonlinux_rep+"/plugins/"+self.current_plugin
        os.remove(self.plugin_path+"/enabled")
        self.LoadPlugins()

    def enable(self, event):
        self.current_plugin = self.pluginlist.GetItemText(self.pluginlist.GetSelection())
        self.plugin_path = Variables.playonlinux_rep+"/plugins/"+self.current_plugin
        enab=open(self.plugin_path+"/enabled",'w')
        enab.close()
        self.LoadPlugins()

    def choose_plugin(self, event):
        self.current_plugin = self.pluginlist.GetItemText(self.pluginlist.GetSelection())
        self.plugin_path = Variables.playonlinux_rep+"/plugins/"+self.current_plugin
        if(os.path.exists(self.plugin_path+"/enabled")):
            self.EnablePlugin.Destroy()
            self.EnablePlugin = wx.Button(self.panels_buttons_plugins, 214, _("Disable"), pos=(100,38))
        else:
            self.EnablePlugin.Destroy()
            self.EnablePlugin = wx.Button(self.panels_buttons_plugins, 213, _("Enable"), pos=(100,38))

        if(os.path.exists(self.plugin_path+"/scripts/options")):
            self.ConfigurePlugin.Enable(True)
        else:
            self.ConfigurePlugin.Enable(False)

        if(os.path.exists(self.plugin_path+"/description")):
            self.txtPlugin.Destroy()
            self.txtPlugin = wx.StaticText(self.panels_buttons_plugins, -1, open(self.plugin_path+"/description","r").read(), size=(285,150), pos=(200,5))

        self.DelPlugin.Enable(True)

    def glxinfo(self, event):
        glx = os.popen("glxinfo", "r").read()
        self.txtGLX.SetValue(glx)

    def xorg(self, event):
        glx = open("/etc/X11/xorg.conf", "r").read()
        self.txtGLX.SetValue(glx)

    def glxgears(self, event):
        self.result = os.popen("glxgears", "r").read()
        self.txtGLX.SetValue(self.result)

    def system_info(self, event):
        self.txtGLX.SetValue(os.popen("bash \""+Variables.playonlinux_env+"/bash/system_info\" &", "r").read())

    def SupprimePage(self, index):
        self.DeletePage(index)


class MainWindow(wx.Frame):
    def __init__(self,parent,id,title,onglet):
        wx.Frame.__init__(self, parent, -1, title, size = (505, 550), style = wx.CLOSE_BOX | wx.CAPTION | wx.MINIMIZE_BOX)
        self.SetIcon(wx.Icon(Variables.playonlinux_env+"/etc/playonlinux.png", wx.BITMAP_TYPE_ANY))
        self.panelFenp = wx.Panel(self, -1)
        self.panels_buttons = wx.Panel(self.panelFenp, -1)
        self.Apply = wx.Button(self.panels_buttons, wx.ID_APPLY, _("Apply"), pos=(400,0), size=(100,35))
        self.Close = wx.Button(self.panels_buttons, wx.ID_CLOSE, _("Cancel"), pos=(295,0), size=(100,35))
        self.sizer = wx.BoxSizer(wx.VERTICAL)
        self.onglets = Onglets(self.panelFenp)

        self.sizer.Add(self.onglets, 12, wx.EXPAND|wx.ALL, 2)
        self.sizer.Add(self.panels_buttons, 1, wx.EXPAND|wx.ALL, 2)

        #self.onglets.General(_("General"))
        self.onglets.Internet(_("Internet"))
        #self.onglets.Wine(_("Environment"))
        #self.onglets.System(_("System"))
        self.onglets.Plugins(_("Plugins"))
        self.onglets.Extensions(_("File associations"))

        try:
            self.onglets.SetSelection(onglet)
        except:
            pass

        self.panelFenp.SetSizer(self.sizer)
        self.panelFenp.SetAutoLayout(True)
        wx.EVT_BUTTON(self, wx.ID_APPLY, self.apply_settings)
        wx.EVT_BUTTON(self, wx.ID_CLOSE, self.app_Close)

    def app_Close(self, event):
        self.Destroy()

    def apply_settings(self, event):
        playonlinux.SetSettings("PROXY_ENABLED",str(int(self.onglets.ProxyCheck.IsChecked())))
        if(self.onglets.ProxyCheck.IsChecked()):
            playonlinux.SetSettings("PROXY_URL",self.onglets.ProxyAdresse.GetValue().replace("http://",""))
            playonlinux.SetSettings("PROXY_PORT",self.onglets.ProxyPort.GetValue())
            playonlinux.SetSettings("PROXY_LOGIN",self.onglets.ProxyLogin.GetValue())
            playonlinux.SetSettings("PROXY_PASSWORD",self.onglets.ProxyPass.GetValue())


        wx.MessageBox(_("You must restart {0} for the changes to take effect.").format(os.environ["APPLICATION_TITLE"]), os.environ["APPLICATION_TITLE"], wx.OK)
        self.Destroy()



#!/usr/bin/env python
# Copyright (C) 2007-2010 PlayOnLinux Team
# Copyright (C) 2011 - Quentin PARIS

import os, random, sys, string
import wx, lib.playonlinux as playonlinux

# Un ptit check
try :
    os.environ["POL_OS"]
except :
    print "ERROR ! Please define POL_OS environment var first."
    os._exit(1)

# Variables mixte 1
os.environ["POL_PORT"] = "0"
os.environ["PLAYONLINUX"] = os.path.realpath(os.path.realpath(__file__)+"/../../../")
os.environ["SITE"] = "http://repository.playonlinux.com"
os.environ["VERSION"] = "4.2.2"
os.environ["POL_ID"] = str(random.randint(1,100000000))
os.environ["WINE_SITE"] = "http://www.playonlinux.com/wine/binaries"
os.environ["GECKO_SITE"] = "http://www.playonlinux.com/wine/gecko"
os.environ["MONO_SITE"] = "http://www.playonlinux.com/wine/mono"
homedir = os.environ["HOME"]

# Debian packagers should switch this to TRUE
# It will disable update alerts, bug reports, statistics
# It will set the good locale directory, and it will use the good msttcorefonts
os.environ["DEBIAN_PACKAGE"] = "FALSE"

# Variables PlayOnMac
if (os.environ["POL_OS"] == "Mac"):
    os.environ["PLAYONMAC"] = os.environ["PLAYONLINUX"]
    os.environ["REPERTOIRE"] = os.environ["HOME"]+"/Library/PlayOnMac/"
    os.environ["APPLICATION_TITLE"] = "PlayOnMac"
    os.environ["POL_DNS"] = "playonmac.com"
    windows_add_size = 20;
    windows_add_playonmac = 1;
    widget_borders = wx.SIMPLE_BORDER
    os_name = "darwin"
    os.environ["POL_WGET"] = "wget --prefer-family=IPv4 -q"

# Variables PlayOnLinux
if (os.environ["POL_OS"] == "Linux"):
    os.environ["REPERTOIRE"] = os.environ["HOME"]+"/.PlayOnLinux/"
    os.environ["APPLICATION_TITLE"] = "PlayOnLinux"
    os.environ["POL_DNS"] = "playonlinux.com"
    windows_add_size = 0;
    windows_add_playonmac = 0;
    widget_borders = wx.RAISED_BORDER
    os_name = "linux"
    if not os.path.exists("/proc/net/if_inet6"):
        os.environ["POL_WGET"] = "wget -q"
    else:
        os.environ["POL_WGET"] = "wget --prefer-family=IPv4 -q"

os.environ["POL_CURL"] = "curl"

archi = string.split(os.environ["MACHTYPE"],"-")
archi = archi[0]

if(archi == "x86_64" and os.environ["POL_OS"] == "Linux"):
    os.environ["AMD64_COMPATIBLE"] = "True"
else:
    os.environ["AMD64_COMPATIBLE"] = "False"

# Variables mixtes
os.environ["POL_USER_ROOT"] = os.environ["REPERTOIRE"]
os.environ["TITRE"] = os.environ["APPLICATION_TITLE"]
os.environ["WINEPREFIX"] = os.environ["REPERTOIRE"]+"/wineprefix/default"
os.environ["OS_NAME"] = os_name

# Wine
os.environ["WINEDLLOVERRIDES"] = "winemenubuilder.exe=d"

# Si DYLD_LIBRARY_PATH n'existe pas, on la defini pour etre sur
try :
    os.environ["DYLD_LIBRARY_PATH"]
except:
    os.environ["DYLD_LIBRARY_PATH"] = ""

# Pareil pour LD
try :
    os.environ["LD_LIBRARY_PATH"]
except:
    os.environ["LD_LIBRARY_PATH"] = ""




if (os.environ["POL_OS"] == "Mac"):
    os.environ["MAGICK_HOME"] = os.environ["PLAYONLINUX"]+"/../unix/image_magick/"

    os.environ["PATH"] = os.environ["PLAYONLINUX"]+"/../unix/wine/bin:" + os.environ["PLAYONLINUX"]+"/../unix/image_magick/bin:" + os.environ["PLAYONLINUX"]+"/../unix/tools/bin/:" + os.environ["PATH"]

    os.environ["LD_LIBRARY_PATH"] =  os.environ["PLAYONLINUX"]+"/../unix/wine/lib/:"  + os.environ["PLAYONLINUX"]+"/../unix/image_magick/lib:"+ os.environ["PLAYONLINUX"]+"/../unix/tools/lib/ld:/usr/X11/lib/:" + os.environ["LD_LIBRARY_PATH"]

    os.environ["DYLD_LIBRARY_PATH"] = os.environ["PLAYONLINUX"]+"/../unix/tools/lib/dyld:" + os.environ["PLAYONLINUX"]+"/../unix/image_magick/lib:"+ os.environ["DYLD_LIBRARY_PATH"]
else:
    # Debian maintainer decided for some reason not to let wineserver binary into PATH...
    for winepath in ('/usr/lib/wine', '/usr/lib/wine-unstable', \
                     '/usr/lib/i386-linux-gnu/wine', '/usr/lib/i386-linux-gnu/wine-unstable', \
                     '/usr/lib32/wine', '/usr/lib32/wine-unstable'):
        if os.path.exists('%s/wineserver' % (winepath,)):
            os.environ["PATH"] += ':%s' % (winepath,)
            break

os.environ["PATH_ORIGIN"] = os.environ["PATH"]
os.environ["LD_PATH_ORIGIN"] = os.environ["LD_LIBRARY_PATH"]
os.environ["DYLDPATH_ORIGIN"] = os.environ["DYLD_LIBRARY_PATH"]

playonlinux_env = os.environ["PLAYONLINUX"]
playonlinux_rep = os.environ["REPERTOIRE"]
version = os.environ["VERSION"]
current_user = os.environ["USER"]

os.environ["WGETRC"] = os.environ["POL_USER_ROOT"]+"/configurations/wgetrc"

## Proxy settings
if(playonlinux.GetSettings("PROXY_ENABLED") == "1"):
    if(playonlinux.GetSettings("PROXY_URL") != ""):
        if(playonlinux.GetSettings("PROXY_LOGIN") == ""):
            http_proxy = "http://"+playonlinux.GetSettings("PROXY_URL")+":"+playonlinux.GetSettings("PROXY_PORT")
        else:
            http_proxy = "http://"+playonlinux.GetSettings("PROXY_LOGIN")+":"+playonlinux.GetSettings("PROXY_PASSWORD")+"@"+playonlinux.GetSettings("PROXY_URL")+":"+playonlinux.GetSettings("PROXY_PORT")
        os.environ["http_proxy"] = http_proxy



#!/usr/bin/python
# -*- coding:Utf-8 -*-
import threading
import Variables
import time
import socket
import string
import os, math
import wx
import re
global allowed_people
global refused_people
allowed_people = []
refused_people = []
class IRCClient(threading.Thread):
    string_to_write = ""
    def __init__(self):
        threading.Thread.__init__(self)
        # https://www.freenode.net/irc_servers.shtml
        self.serveur = "chat.freenode.net"
        self.port = 6667
        self.Nick = Variables.current_user+"-pol"
        self.chanAutoJoin = "#playonlinux"
        self.start()
        self.freenode_tried = False

    def get_list(self, chan):
        if(self.ircconnected == True):
            self.connexion.send('NAMES '+chan+'\r\n')

    def htmlspecialchars(self, string):
        self.string = string.replace("<","&lt;")
        self.string = self.string.replace(">","&gt;")
        return self.string

    def _vivify(self, matchobj):
        url = matchobj.group(1)
        return "<A href=\"%s\">%s</A>" % (url, url)

    def urlvivify(self, string):
        return re.sub(r'((?:[fF][tT][pP]://|[hH][tT][tT][pP][sS]?://|[nN][eE][wW][sS]://)[-a-zA-Z0-9._/%?=&#]*)', self._vivify, string, 0)

    def connect(self): # Se connecte au serveur IRC
        if(self.ircconnected == False):
            self.status_messages.append(self.html_convert(None, "Connecting ...","#AA0000","#AA0000",True))
            try:
                self.connexion = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
                self.connexion.connect((self.serveur, self.port))
                self.ircconnected = True
                self.connexion.send('NICK' + ' ' + self.Nick + '\r\n')
                self.realname = os.environ["APPLICATION_TITLE"]+" Client "+os.environ["VERSION"]
                self.connexion.send('USER' + ' PlayOnLinux ' + self.Nick + ' ' + self.serveur + ' :' + self.realname + '\r\n')
            except:
                self.status_messages.append(self.html_convert(None, "Error! Unable to connect. Check your internet connexion and try again.","#AA0000","#AA0000",True))
                self.stop()
        else:
            self.status_messages.append(self.html_convert(None, "You are in offline-mode","#AA0000","#AA0000",True))


    def getSettings(self):
        irc_settings = {}

        irc_settings['NICKNAME'] = os.environ["USER"]+"-pol"
        irc_settings['AUTOCONNECT'] = "0"
        irc_settings['ALERT'] = "0"
        irc_settings["PLAYSOUND"] = "1"
        if(os.path.exists(Variables.playonlinux_rep+"/configurations/options/irc")):
            ircfile = open(Variables.playonlinux_rep+"/configurations/options/irc","r").readlines()
            self.i = 0

            while(self.i < len(ircfile)):
                line_parsed = string.split(ircfile[self.i].replace("\n","").replace("\r",""),"=")
                irc_settings[line_parsed[0]] = line_parsed[1]
                self.i += 1
        return irc_settings

    def getNick(self, chaine):
        self.nickname = string.split(chaine, "!")
        self.nickname = self.nickname[0]
        self.nickname = self.nickname[1:len(self.nickname)]
        return self.nickname

    def ChangeNick(self, nick):
        if(self.ircconnected == True):
            self.connexion.send("NICK :"+nick+"\r\n")
            self.Nick = nick


    def GenColor(self, pseudo):
        self.colors = ["000","F00","00F","080","008","010","02E","02F","D60","D80","DA0","E00","E40","E50","E70","E80","F24","F42","777"
                       "06F","090","0A0","0AD","0C0","0F0","0CF","150","209","21F","D11","D12","D13","D20","D40","EA0","F27","F43","666"
                       "280","29E","300","30F","32F","34F","36F","470","560","5A0","5AF","5F0","64F","750","800","850","F28","F44","999"
                       "A90","A80","A00","A0F","A1E","A1C","A08","A70","C40","C30","C60","C80","CA0","D10","EC0","EC1","F29","F45","222"
                       "EC2","EC3","ED1","ED0","ED3","F10","F11","F12","F13","F14","F20","F21","F22","F23","F24","F26","F41","090",
                       "F91","F92","F93","F94","F95","F96","F97","F98","F99","F9A","F9A","F9C","F9D","F9E","F9F","0A0","0A1","0A2",
                       "0D0","0D1","0D2","0D3","0D4","0D5","0D6","0D7","0D8","0D9","0DA","0DA","0DC","0DD","0DE","0DF","FE0","FE1",
                       "FE2","FD0","FD1","FD2","160","161","162","163","164","165","166","170","171","173","174","175","176","#AAA"]
        #self.colors.sort()
        self.colors.reverse()

        i = 0
        somme = 0
        max = 0
        while(i < len(pseudo)):
            i += 1
            somme += ord(pseudo[i - 1])*i
            max += 127*i



        num=math.cos(somme * len(self.colors) / max) * len(self.colors)
        num=int(num)
        #print num
        return "0x"+self.colors[num]

    def smile(self, string):
        self.newstring = string
        self.newstring = self.newstring.replace("O:-)","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-angel.png'>")
        self.newstring = self.newstring.replace(":-)","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-smile.png'>")
        self.newstring = self.newstring.replace(":)","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-smile.png'>")
        self.newstring = self.newstring.replace(":-(","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-sad.png'>")
        self.newstring = self.newstring.replace(":(","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-sad.png'>")
        self.newstring = self.newstring.replace(":'(","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-crying.png'>")
        self.newstring = self.newstring.replace("(6)","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-devilish.png'>")
        self.newstring = self.newstring.replace("8-)","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-glasses.png'>")
        self.newstring = self.newstring.replace(":-O","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-surprise.png'>")
        self.newstring = self.newstring.replace(":-D","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-grin.png'>")
        self.newstring = self.newstring.replace(":D","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-grin.png'> ")
        self.newstring = self.newstring.replace(":-*","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-kiss.png'>")
        self.newstring = self.newstring.replace("(monkey)","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-monkey.png'>")
        self.newstring = self.newstring.replace(":-|","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-plain.png'>")
        self.newstring = self.newstring.replace(":|","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-plain.png'> ")
        self.newstring = self.newstring.replace(";-)","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-wink.png'> ")
        self.newstring = self.newstring.replace(";)","<img src='"+Variables.playonlinux_env+"/resources/images/emotes/face-wink.png'> ")
        return self.newstring

    def playsound(self):
        settings = self.getSettings()
        if(settings["PLAYSOUND"] == "1"):
            #os.system("playsound "+Variables.playonlinux_env+"/etc/snd/snd.wav & 2> /dev/null > /dev/null")
            sound = wx.Sound(Variables.playonlinux_env+"/resources/sounds/irc.wav")
            sound.Play(wx.SOUND_SYNC)

    def join(self, chan):
        if(chan.lower() not in self.chans and self.ircconnected == True):
            if(chan[0] == "#"):
                self.connexion.send("JOIN :"+chan+"\r\n")
            self.chans.append(chan.lower())
            self.endnames.append(False)
            self.names.append([])
            self.messages.append([])

        self.select_window = chan.lower()

            #self.open_window.append(chan.lower())
            #self.get_list(chan)

    def leave_chan(self, chan):
        if(chan.lower() in self.chans and self.ircconnected == True):
            index = self.get_index(chan)
            if(chan[0] == "#"):
                self.connexion.send("PART :"+chan+"\r\n")

            del self.messages[index]
            del self.names[index]
            del self.endnames[index]
            del self.chans[index]
            self.select_window = self.chanAutoJoin

    def html_convert(self, pseudo, message, pseudocolor='#000000', messagecolor='#000000', action = False):
        tps = time.strftime("%H:%M:%S")
        message = message.replace("  "," &nbsp;")
        message = message.replace("\x1f","")
        message = message.replace("\x02","")
        message = self.htmlspecialchars(message)
        message = self.urlvivify(message)
        message = self.smile(message)
        if(pseudo != None):
            if(action == False):
                return "<font color='"+pseudocolor+"'>("+tps+") <b>"+pseudo+":</b> </font><font color='"+messagecolor+"'>"+message+"</font>"
            else:
                return "<font color='"+pseudocolor+"'>("+tps+") <b>*** "+pseudo+"</b> </font><font color='"+messagecolor+"'>"+message+"</font>"
        else :
            return "<font color='"+messagecolor+"'>("+tps+") "+message+"</font>"
    def get_index(self, content):
        self.boucle = 0
        while(self.boucle < len(self.chans)):
            if(self.chans[self.boucle].lower() == content):
                return self.boucle
            self.boucle +=1

        return -1

    def getMsg(self, array, num=3):
        self.boucle = num
        self.chaine = ""
        while(self.boucle < len(array)):
            self.chaine += array[self.boucle]+" "
            self.boucle += 1
        return self.chaine[1:len(self.chaine)-1]

    def check_access(self, window, i=0):
        print("Try #"+str(i))
        if(window in allowed_people):
            return True
        elif(window in refused_people):
            return False
        else:
            if(i == 0):
                self.connexion.send("PRIVMSG PlayOnLinux :CHECK_ACCESS "+window+"\r\n")
            if(i <= 5):
                time.sleep(1)
                return self.check_access(window, i+1)
            else:
                return False

    def SendMSG(self, message, chan="~current"):
        if(self.ircconnected == False):
            self.status_messages.append(self.html_convert(None, "You are not connected.","#FF0000","#FF0000",True))
        else :
            if(message[0] == "/"): # Une commande
                self.message_parsed = string.split(message," ")
                if(self.message_parsed[0].lower() == "/join" and len(self.message_parsed) > 1):
                    if(self.message_parsed[1][0] == "#"):
                        newchan = self.message_parsed[1].lower()
                    else:
                        newchan = "#"+self.message_parsed[1].lower()
                    self.join(newchan)

                if(self.message_parsed[0].lower() == "/query" and len(self.message_parsed) > 1):
                    newchan = self.message_parsed[1].lower()
                    self.join(newchan)

                if(self.message_parsed[0].lower() == "/kick" and len(self.message_parsed) > 1):
                    user = self.message_parsed[1].lower()
                    if(len(self.message_parsed) > 2):
                        self.i = 2
                        message = ""
                        while(self.i < len(self.message_parsed)):
                            if(self.i != 2):
                                message += " "
                            message += self.message_parsed[self.i]
                            self.i += 1
                    else :
                        message = self.Nick

                    self.connexion.send("KICK "+self.selected_window+" "+user+" "+message+"\r\n")

                if(self.message_parsed[0].lower() == "/nick" and len(self.message_parsed) > 1):
                    self.ChangeNick(self.message_parsed[1])

                if(self.message_parsed[0].lower() == "/me" and len(self.message_parsed) > 1):
                    if(chan == "~current"):
                        window = self.selected_window
                    else:
                        window = chan
                    self.connexion.send("PRIVMSG "+window+" :\x01ACTION "+message.replace("/me ","")+" \x01\r\n")
                    self.index = self.get_index(window)
                    self.messages[self.index].append(self.html_convert(self.Nick,message.replace("/me ",""),"#000088","#000088",True))

                if((self.message_parsed[0].lower() == "/msg" or self.message_parsed[0].lower() == "/privmsg") and len(self.message_parsed) > 2):
                    self.join(self.message_parsed[1].lower())
                    self.i = 2
                    message = ""

                    while(self.i < len(self.message_parsed)):
                        if(self.i != 2):
                            message += " "
                        message += self.message_parsed[self.i]
                        self.i += 1


                    self.connexion.send("PRIVMSG "+self.message_parsed[1].lower()+" :"+message+"\r\n")
                    self.index = self.get_index(self.message_parsed[1].lower())
                    self.messages[self.index].append(self.html_convert(self.Nick,message,"#000088","#000088",True))

            else:
                if(chan == "~current"):
                    window = self.selected_window
                else:
                    window = chan

                if self.check_access(window):
                    self.connexion.send("PRIVMSG "+window+" :"+message+"\r\n")

                    self.index = self.get_index(window)
                    if(window[0] != "#"):
                        self.messages[self.index].append(self.html_convert(self.Nick,message,"#000088"))
                    else:
                        self.messages[self.index].append(self.html_convert(self.Nick,message,str(self.GenColor(self.Nick)).replace("0x","#")))
                else:
                    wx.MessageBox(_("Sorry, this person does not want to receive private messages").format(os.environ["APPLICATION_TITLE"]),_("Error"))

    def filtrer_liste(self, liste):
        self.boucle = 0
        self.new_list = []
        while(self.boucle < len(liste)):
            self.new_list.append(liste[self.boucle].replace("@","").replace("+","").replace("&","").replace("%","").replace("~","").lower())
            self.boucle += 1

        return self.new_list

    def traiter(self, line):
        if(len(self.names) > 1 and "@PlayOnLinux" not in self.names[1] and self.endnames[1] == True):
            self.status_messages.append(self.html_convert(None, _("Sorry {0} messenger service is not available for the moment.\n\nPlease retry later").format(os.environ["APPLICATION_TITLE"]),"#AA0000","#AA0000",True))
            self.stop()

        self.line = string.split(line, " ") # On parse la ligne mot par mot
        # On répond aux pings
        if(self.line[0] and len(self.line) > 1):
            self.message_id = self.line[1]
            if(self.line[0] == "PING"): # PINGS
                self.connexion.send("PONG "+self.line[1]+"\r\n")



            if(self.message_id == '353'): # NAMES
                if(len(self.line) > 4):
                    self.canal = self.line[4].lower()
                    self.canal_index = self.get_index(self.canal)
                    if(self.canal_index != -1):
                        if(self.endnames[self.canal_index] == True):
                            self.names[self.canal_index] = []
                            self.endnames[self.canal_index] = False

                        self.boucle = 5
            #                       self.names[self.canal_index].append(self.message_id[4])
                        while(self.boucle < len(self.line)):
                            if(self.line[self.boucle] != ''):
                                self.names[self.canal_index].append(self.line[self.boucle].replace(":",""))
                            self.boucle +=1

            if(self.message_id == '366'): # END NAMES
                if(len(self.line) > 3):
                    self.canal = self.line[3].lower()
                    self.canal_index = self.get_index(self.canal)
                    if(self.canal_index != -1):
                        self.endnames[self.canal_index] = True

            if(self.message_id == '001'): # CONNECTED
                self.join(self.chanAutoJoin)

            if(self.message_id == '332'): # topic
                self.subject = self.getMsg(self.line, 4)
                if(len(self.line) > 3):
                    self.chan = self.line[3].lower()
                    self.chan_index = self.get_index(self.chan)
                    self.messages[self.chan_index].append(self.html_convert(None,"Welcome to "+self.chan+"","#666666","#666666",True))
                    self.messages[self.chan_index].append(self.html_convert(None,"The topic is : "+self.subject+"","#666666","#666666",True))

            if(self.message_id == 'TOPIC'):
                if(len(self.line) > 2):
                    self.sender = self.getNick(self.line[0])
                    self.chan = self.line[2].lower()
                    self.subject = self.getMsg(self.line)
                    self.messages[self.chan_index].append(self.html_convert(self.sender," has defined the topic : "+self.subject+"","#666666","#666666",True))

            if(self.message_id == '474'): # Banned
                if(len(self.line) > 3):
                    self.chan = self.line[3].lower()
                    self.chan_index = self.get_index(self.chanAutoJoin)

                    if(self.chan == self.chanAutoJoin):
                        self.status_messages.append(self.html_convert(None,"Unable to join the chat : You have been banned","#AA0000","#AA0000",True))
                        self.stop()
                    else:
                        self.messages[self.chan_index].append(self.html_convert(None,"Unable to join "+self.chan+" : You have been banned","#AA0000","#AA0000",True))
                        self.leave_chan(self.chan)
            #[':irc.steredenn.fr', '474', 'tinou-pol', '#playonlinux', ':Cannot', 'join', 'channel', '(+b)']

            if(self.message_id == 'JOIN'):
                if(len(self.line) > 2):
                    self.sender = self.getNick(self.line[0])
                    self.window = self.line[2].lower().replace(":","")
                    self.index = self.get_index(self.window)
                    message = " has joined "+self.window
                    self.messages[self.index].append(self.html_convert(self.sender,message,"#888888","#888888",True))
                    self.get_list(self.chans[self.index])

            if(self.message_id == 'PART'):
                if(len(self.line) > 2):
                    self.sender = self.getNick(self.line[0])
                    self.window = self.line[2].lower().replace(":","")
                    self.index = self.get_index(self.window)
                    message = " has left "+self.window
                    self.messages[self.index].append(self.html_convert(self.sender,message,"#888888","#888888",True))
                    self.get_list(self.chans[self.index])

            if(self.message_id == '401'): # No such nick channels
                if(len(self.line) > 3):
                    self.msg_to = self.line[3]
                    message = " is offline"
                    self.index = self.get_index(self.msg_to)
                    self.messages[self.index].append(self.html_convert(self.msg_to,message,"#888888","#888888",True))

            if(self.message_id == '482'): # No such nick channels
                message = "Your not channel operator"
                self.index = self.get_index(self.selected_window)
                self.messages[self.index].append(self.html_convert(None,message,"#888888","#888888",True))

            if(self.message_id == 'NICK'):
                if(len(self.line) > 2):
                    self.sender = self.getNick(self.line[0])
                    self.new_nick = self.line[2].replace(":","")
                    message = " is known as "+self.new_nick
                    self.i = 0
                    while(self.i < len(self.chans)):
                        if(self.sender.lower() in self.filtrer_liste(self.names[self.i])):
                            self.messages[self.i].append(self.html_convert(self.sender,message,"#888888","#888888",True))
                            self.get_list(self.chans[self.i])
                        self.i += 1

            if(self.message_id == 'MODE'):
                if(len(self.line) > 3):
                    self.chan = self.line[2].lower()
                    if(len(self.line) > 4):
                        self.victime = self.line[4]
                    else:
                        self.victime = None

                    self.index = self.get_index(self.chan)
                    self.sender = self.getNick(self.line[0])

                    if("+v" in self.line[3] or "-v" in self.line[3]):
                        self.get_list(self.chan)

                    if("+o" in self.line[3]):
                        message = " has given operator acces to "+self.victime
                        self.messages[self.index].append(self.html_convert(self.sender,message,"#AA0000","#AA0000",True))
                        self.get_list(self.chan)

                    if("-o" in self.line[3]):
                        message = " has removed operator acces to "+self.victime
                        self.messages[self.index].append(self.html_convert(self.sender,message,"#AA0000","#AA0000",True))
                        self.get_list(self.chan)

                    if("+h" in self.line[3]):
                        message = " has given half-operator acces to "+self.victime
                        self.messages[self.index].append(self.html_convert(self.sender,message,"#AA0000","#AA0000",True))
                        self.get_list(self.chan)

                    if("-h" in self.line[3]):
                        message = " has removed half-operator acces to "+self.victime
                        self.messages[self.index].append(self.html_convert(self.sender,message,"#AA0000","#AA0000",True))
                        self.get_list(self.chan)

                    if("+b" in self.line[3]):
                        message = " has banned "+self.victime
                        self.messages[self.index].append(self.html_convert(self.sender,message,"#AA0000","#AA0000",True))
                        self.get_list(self.chan)

                    if("-b" in self.line[3]):
                        message = " has unbanned "+self.victime
                        self.messages[self.index].append(self.html_convert(self.sender,message,"#AA0000","#AA0000",True))
                        self.get_list(self.chan)

            if(self.message_id == '433'): # Nick already in use
                self.status_messages.append(self.html_convert(None, "Error : Nickname already in use","#FF0000","#FF0000",True))
                self.stop()

            if(self.message_id == '432'): # Nick contain illegal caracteres
                self.status_messages.append(self.html_convert(None, "Error : Nickname contains illegal characters","#FF0000","#FF0000",True))
                self.stop()

            if(self.line[0] == 'ERROR'): # Nick contain illegal caracteres
                self.stop()

            if(self.message_id == "KICK"):
                if(len(self.line) > 3):
                    self.sender = self.getNick(self.line[0])
                    self.kicked = self.line[3]
                    self.chan = self.line[2].lower()
                    self.index = self.get_index(self.chan)
                    self.raison = self.getMsg(self.line,4)
                    self.chan_index = self.get_index(self.chanAutoJoin)

                    if(self.kicked.lower() == self.Nick.lower()):
                        if(self.chan == self.chanAutoJoin):
                            self.status_messages.append(self.html_convert(self.sender," has kicked you from the chat : "+self.raison,"#FF0000","#FF0000",True))
                            self.stop()
                        else :
                            self.messages[self.chan_index].append(self.html_convert(self.sender," has kicked you from "+self.chan+" : "+self.raison,"#FF0000","#FF0000",True))
                            self.leave_chan(self.chan)
                    else :
                        self.messages[self.index].append(self.html_convert(self.sender," has been kicked "+self.kicked+" from "+self.chan+" : "+self.raison,"#888888","#888888",True))
                    self.get_list(self.chan)

            if(self.message_id == 'QUIT'):
                self.sender = self.getNick(self.line[0])
                self.i = 0
                message = " has quit"
                while(self.i < len(self.chans)):
                    if(self.sender.lower() in self.filtrer_liste(self.names[self.i])):
                        self.messages[self.i].append(self.html_convert(self.sender,message,"#888888","#888888",True))
                        self.get_list(self.chans[self.i])
                    self.i += 1

            if(self.message_id == 'PRIVMSG' or self.message_id == 'NOTICE' and len(self.line) > 2):
                self.sender = self.getNick(self.line[0])
                if(self.line[2][0] == "#"):
                    self.window = self.line[2].lower()
                    if(self.Nick.lower() not in self.getMsg(self.line)):
                        self.generated_color = str(self.GenColor(self.sender)).replace("0x","")
                        self.color = "#"+self.generated_color[0]+self.generated_color[0]+self.generated_color[1]+self.generated_color[1]+self.generated_color[2]+self.generated_color[2]# Pseudo normal

                        self.message_color = "#000000"
                    else :
                        self.color = "#EE00EE"
                        self.message_color = "#EE00EE"
                        self.playsound()

                else:
                    if(self.sender.lower() != "playonlinux"):
                        self.color = "#AA0000"
                        self.message_color = "#000000"
                        self.window = self.sender.lower()
                        if(self.window != self.selected_window and not "." in self.window):
                            self.playsound()
                        self.old_window = self.selected_window
                        if(self.window not in self.chans):
                            self.chans.append(self.window)
                            self.endnames.append(False)
                            self.names.append([])
                            self.messages.append([])
                        if(self.old_window != ""):
                            self.select_window = self.old_window

                self.index = self.get_index(self.window)
                if("\x01ACTION" in self.getMsg(self.line)):
                    message = self.getMsg(self.line).replace("\x01","")
                    message = message[6:len(message)]
                    if(self.sender.lower() != "playonlinux"):
                        self.messages[self.index].append(self.html_convert(self.sender,message,"#000088","#000088",True))
                else :
                    message = self.getMsg(self.line)
                    if(self.sender.lower() != "playonlinux"):
                        self.messages[self.index].append(self.html_convert(self.sender,message,self.color,self.message_color))
                    else:
                        message_split = message.split(" ")
                        if(len(message_split) >= 2):
                            if(message_split[0] == "ALLOW"):
                                allowed_people.append(message_split[1])
                            elif(message_split[0] == "DENY"):
                                refused_people.append(message_split[1])

            #print self.names
    def run(self):
        self.ircconnected = False
        self.selected_window = self.chanAutoJoin
        self.names = []
        self.messages = []
        self.chans = []
        self.endnames = []
        self.select_window = ""
        self.status_messages = []
       # self.open_window = []
        while 1:
            if(self.ircconnected == True):
                #select([self.connexion], [], [])
                self.dataRecv = self.connexion.recv(1024)
                self.contentParse_ = string.split(self.dataRecv,"\r\n")
                self.k = 0
                while(self.k < len(self.contentParse_)):
                    if(self.contentParse_[self.k]):
                        self.traiter(self.contentParse_[self.k])
                    self.k += 1
            else:
                time.sleep(0.1)

    def Connexion(self):
        self.connect()

    def stop(self):
        if(self.ircconnected == True):
               # self.zone_append("<font color='#666666'>("+time.strftime("%H:%M:%S")+") Disconnected</font>")
            self.ircconnected = False
            self.status_messages.append(self.html_convert(None, "Disconnected","#AA0000","#AA0000",True))
            self.connexion.send("QUIT :www.playonlinux.com\r\n")
            self.connexion.close()
            self.names = []
            self.messages = []
            self.chans = []
            self.endnames = []



#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Copyright (C) 2007 Pâris Quentin
# Copyright (C) 2007-2010 PlayOnLinux Team

# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.

# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

import wxversion, os, getopt, sys, urllib, signal, socket, codecs, string, shutil, time, urllib, urllib2
import wx, wx.animate

import lib.Variables as Variables
import lib.lng, threading

if(os.environ["POL_OS"] == "Mac"):
    os_pref = "darwin"
else:
    os_pref = "linux"

lib.lng.Lang()

def SetWineVersion(game, version):
    cfile = Variables.playonlinux_rep+"shortcuts/"+game
    fichier = open(cfile,"r").readlines()
    i = 0
    line = []
    while(i < len(fichier)): # On retire l'eventuel
        fichier[i] = fichier[i].replace("\n","")
        if("PATH=" not in fichier[i] or "WineVersions" not in fichier[i]):
            line.append(fichier[i])
        i += 1

    fichier_write = open(cfile,"w")

    if(version != "System"): # On insere
        if(os.environ["POL_OS"] == "Mac"):
            line.insert(1,"PATH=\""+Variables.playonlinux_rep+"WineVersions/"+version+"/bin/:$PATH\"")
            line.insert(1,"LD_LIBRARY_PATH=\""+Variables.playonlinux_rep+"WineVersions/"+version+"/lib/:$LD_LIBRARY_PATH\"")
        else:
            line.insert(1,"PATH=\""+Variables.playonlinux_rep+"WineVersions/"+version+"/usr/bin/:$PATH\"")
            line.insert(1,"LD_LIBRARY_PATH=\""+Variables.playonlinux_rep+"WineVersions/"+version+"/usr/lib/:$LD_LIBRARY_PATH\"")


    i = 0
    while(i < len(line)): # On ecrit
        fichier_write.write(line[i]+"\n")
        i+=1

def GetWineVersion(game):
    cfile = Variables.playonlinux_rep+"shortcuts/"+game
    fichier = open(cfile,"r").readlines()
    i = 0
    line = ""
    while(i < len(fichier)):
        fichier[i] = fichier[i].replace("\n","")
        if("PATH=" in fichier[i] and "WineVersions" in fichier[i]):
            line = fichier[i].replace("//","/")
        i += 1

    if(line == ""):
        version = "System"
    else:
        version=line.replace("PATH=","").replace("\"","").replace(Variables.playonlinux_rep,"").replace("//","/")
        version = string.split(version,"/")
        version = version[1]

    return(version)


def keynat(string):
    r'''A natural sort helper function for sort() and sorted()
    without using regular expressions or exceptions.

    >>> items = ('Z', 'a', '10th', '1st', '9')
    >>> sorted(items)
    ['10th', '1st', '9', 'Z', 'a']
    >>> sorted(items, key=keynat)
    ['1st', '9', '10th', 'a', 'Z']

    Borrowed from http://code.activestate.com/recipes/285264/#c6
    by paul clinch.

    License is the PSF Python License, http://www.python.org/psf/license/ (GPL compatible)
    '''
    it = type(1)
    r = []
    for c in string:
        if c.isdigit():
            d = int(c)
            if r and type( r[-1] ) == it:
                r[-1] = r[-1] * 10 + d
            else:
                r.append(d)
        else:
            r.append(c.lower())
    return r

class getVersions(threading.Thread):
    def __init__(self, arch="x86"):
        threading.Thread.__init__(self)
        self.thread_message = "#WAIT#"
        self.versions = []
        self.architecture = arch
        self.start()

    def download(self, game):
        self.getDescription = game

    def run(self):
        self.thread_running = True
        while(self.thread_running):
            if(self.thread_message == "get"):
                wfolder = os_pref+"-"+self.architecture
                try :

                    url = os.environ["WINE_SITE"]+"/"+wfolder+".lst"

                    #print(url)
                    req = urllib2.Request(url)
                    handle = urllib2.urlopen(req, timeout = 2)
                    time.sleep(1)
                    available_versions = handle.read()
                    available_versions = string.split(available_versions,"\n")

                    self.i = 0
                    self.versions_ = []
                    while(self.i < len(available_versions) - 1):
                        informations = string.split(available_versions[self.i], ";")
                        version = informations[1]
                        package = informations[0]
                        sha1sum = informations[2]
                        if(not os.path.exists(Variables.playonlinux_rep+"/wine/"+wfolder+"/"+version)):
                            self.versions_.append(version)
                        self.i += 1
                    self.versions_.reverse()
                    self.versions = self.versions_[:]

                    self.thread_message = "Ok"
                except :
                    time.sleep(1)
                    self.thread_message = "Err"
                    self.versions = ["Wine packages website is unavailable"]

            else:
                time.sleep(0.2)

class Onglets(wx.Notebook):
        # Classe dérivée du wx.Notebook
    def __init__(self, parent):
        self.notebook = wx.Notebook.__init__(self, parent, -1)
        self.images_onglets = wx.ImageList(16, 16)
        self.images_onglets.Add(wx.Bitmap(Variables.playonlinux_env+"/etc/onglet/wine.png"))
        self.SetImageList(self.images_onglets)
        self.panelFenp = {}
        self.imagesapps = {}
        self.imagesapps_i = {}
        self.list_apps = {}
        self.new_panel = {}
        self.list_ver_installed = {}
        self.button_rm = {}
        self.button_in = {}

    def liste_versions(self, arch="x86"):
        if(arch == "amd64"):
            add=100
        else:
            add=0
        self.panelFenp[arch] = wx.Panel(self, -1)
        self.imagesapps[arch] = wx.ImageList(22, 22)
        self.imagesapps_i[arch] = wx.ImageList(22, 22)


        self.list_apps[arch] = wx.TreeCtrl(self.panelFenp[arch], 106+add, style=wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT|Variables.widget_borders, size=(320, 300), pos=(10,35))
        self.list_apps[arch].SetImageList(self.imagesapps[arch])
        self.list_apps[arch].SetSpacing(0);

        self.new_panel[arch] = wx.Panel(self.panelFenp[arch], -1, pos=(10,505), size=(100,100))

        self.list_ver_installed[arch] = wx.TreeCtrl(self.panelFenp[arch], 107+add, style=wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT|Variables.widget_borders, size=(320, 300), pos=(400,35))
        self.list_ver_installed[arch].SetImageList(self.imagesapps_i[arch])
        self.list_ver_installed[arch].SetSpacing(0);
        wx.StaticText(self.panelFenp[arch], -1, _("Installed Wine versions: "),(395,10))
        wx.StaticText(self.panelFenp[arch], -1, _("Available Wine versions: "),(5,10))

        self.button_rm[arch] = wx.Button(self.panelFenp[arch], 108+add, "<", pos=(340, 175), size=(50,30))
        self.button_in[arch] = wx.Button(self.panelFenp[arch], 109+add,">", pos=(340, 125), size=(50,30))

        self.button_rm[arch].Enable(False)
        self.button_in[arch].Enable(False)
        self.AddPage(self.panelFenp[arch], _("Wine versions")+" ("+arch+")", imageId=0)






class MainWindow(wx.Frame):
    def __init__(self,parent,id,title):
        self.download32 = getVersions("x86")
        if(os.environ["AMD64_COMPATIBLE"] == "True"):
            self.download64 = getVersions("amd64")

        wx.Frame.__init__(self, parent, -1, title, size = (750, 400+Variables.windows_add_size), style = wx.CLOSE_BOX | wx.CAPTION | wx.MINIMIZE_BOX)
        self.timer = wx.Timer(self, 1)
        self.SetIcon(wx.Icon(Variables.playonlinux_env+"/etc/playonlinux.png", wx.BITMAP_TYPE_ANY))
        #self.panel = wx.Panel(self, -1)

        self.onglets = Onglets(self)
        #self.sizer = wx.BoxSizer(wx.VERTICAL)
        #self.sizer.Add(self.onglets, 15, wx.EXPAND|wx.ALL, 2)

        self.getVersions("x86")
        if(os.environ["AMD64_COMPATIBLE"] == "True"):
            self.getVersions("amd64")
        #self.panel.SetSizer(self.sizer)
        #self.panel.SetAutoLayout(True)

        self.onglets.liste_versions()
        if(os.environ["AMD64_COMPATIBLE"] == "True"):
            self.onglets.liste_versions("amd64")
        self.oldreload32=""

        if(os.environ["AMD64_COMPATIBLE"] == "True"):
            self.oldreload64=""

        self.oldversions32 = []

        if(os.environ["AMD64_COMPATIBLE"] == "True"):
            self.oldversions64 = []

        #self.button = wx.Button(self.panels_buttons, wx.ID_CLOSE, _("Close"), pos=(510, 5), size=wx.DefaultSize)

        wx.EVT_BUTTON(self, wx.ID_CLOSE, self.closeapp)
        wx.EVT_CLOSE(self, self.closeapp)
        wx.EVT_TREE_SEL_CHANGED(self, 106, self.unselect32)
        wx.EVT_TREE_SEL_CHANGED(self, 107, self.unselect32)
        wx.EVT_BUTTON(self, 108, self.delete32)
        wx.EVT_BUTTON(self, 109, self.install32)

        wx.EVT_TREE_SEL_CHANGED(self, 206, self.unselect64)
        wx.EVT_TREE_SEL_CHANGED(self, 207, self.unselect64)
        wx.EVT_BUTTON(self, 208, self.delete64)
        wx.EVT_BUTTON(self, 209, self.install64)

        self.Bind(wx.EVT_TIMER, self.AutoReload, self.timer)
        self.timer.Start(200)

    def AutoReload(self, event):
        reload32 = os.listdir(Variables.playonlinux_rep+"/wine/"+os_pref+"-x86")
        if(os.environ["AMD64_COMPATIBLE"] == "True"):
            reload64 = os.listdir(Variables.playonlinux_rep+"/wine/"+os_pref+"-amd64")
        if(self.download32.thread_message == "Ok" or self.download32.thread_message == "Err"):
            self.onglets.new_panel["x86"].Hide()
            self.WriteVersion()
            self.download32.thread_message = "Wait"

        else:
            if(self.download32.thread_message != "Wait"):
                self.onglets.new_panel["x86"].Show()


        if(os.environ["AMD64_COMPATIBLE"] == "True"):
            if(self.download64.thread_message == "Ok" or self.download64.thread_message == "Err"):
                self.onglets.new_panel["amd64"].Hide()
                self.WriteVersion("amd64")
                self.download64.thread_message = "Wait"
            else:
                if(self.download64.thread_message != "Wait"):
                    self.onglets.new_panel["amd64"].Show()

        if(os.environ["AMD64_COMPATIBLE"] == "True"):
            if(reload64 != self.oldreload64):
                self.getVersions("amd64")
                self.oldreload64 = reload64

        if(reload32 != self.oldreload32):
            self.getVersions()
            self.oldreload32 = reload32

        if(self.download32.versions != self.oldversions32):
            self.oldversions32 = self.download32.versions[:]

        if(os.environ["AMD64_COMPATIBLE"] == "True"):
            if(self.download64.versions != self.oldversions64):
                self.oldversions64 = self.download64.versions[:]



    def sizedirectory(self, path):
        size = 0
        for root, dirs, files in os.walk(path):
            for fic in files:
                size += os.path.getsize(os.path.join(root, fic))
        return size

    def unselect32(self, event):
        if(event.GetId() == 106):
            self.onglets.list_ver_installed["x86"].UnselectAll()
            self.onglets.button_rm["x86"].Enable(False)
            self.onglets.button_in["x86"].Enable(True)
        if(event.GetId() == 107):
            self.onglets.list_apps["x86"].UnselectAll()
            self.onglets.button_rm["x86"].Enable(True)
            self.onglets.button_in["x86"].Enable(False)

    def delete32(self, event):
        version = self.onglets.list_ver_installed["x86"].GetItemText(self.onglets.list_ver_installed["x86"].GetSelection()).encode("utf-8","replace")

        if(wx.YES == wx.MessageBox(_('Are you sure you want to delete wine {0}?').format(version).decode("utf-8","replace"), os.environ["APPLICATION_TITLE"],style=wx.YES_NO | wx.ICON_QUESTION)):
            shutil.rmtree(Variables.playonlinux_rep+"/wine/"+os_pref+"-x86/"+version)

    def install32(self, event):
        install = self.onglets.list_apps["x86"].GetItemText(self.onglets.list_apps["x86"].GetSelection()).encode("utf-8","replace")
        os.system("bash \""+Variables.playonlinux_env+"/bash/install_wver\" "+install+" x86 &")


    def unselect64(self, event):
        if(event.GetId() == 206):
            self.onglets.list_ver_installed["amd64"].UnselectAll()
            self.onglets.button_rm["amd64"].Enable(False)
            self.onglets.button_in["amd64"].Enable(True)
        if(event.GetId() == 207):
            self.onglets.list_apps["amd64"].UnselectAll()
            self.onglets.button_rm["amd64"].Enable(True)
            self.onglets.button_in["amd64"].Enable(False)

    def delete64(self, event):
        version = self.onglets.list_ver_installed["amd64"].GetItemText(self.onglets.list_ver_installed["amd64"].GetSelection()).encode("utf-8","replace")
        if(wx.YES == wx.MessageBox("Are you sure you want to delete wine "+version+"?", style=wx.YES_NO | wx.ICON_QUESTION)):
            shutil.rmtree(Variables.playonlinux_rep+"/wine/"+os_pref+"-amd64/"+version)

    def install64(self, event):
        install = self.onglets.list_apps["amd64"].GetItemText(self.onglets.list_apps["amd64"].GetSelection()).encode("utf-8","replace")
        os.system("bash \""+Variables.playonlinux_env+"/bash/install_wver\" "+install+" amd64 &")

    def getVersions(self, arch="x86"):
        if(arch == "x86"):
            self.download32.thread_message = "get"
        if(arch == "amd64"):
            self.download64.thread_message = "get"


    def WriteVersion(self, arch="x86"):
        self.onglets.imagesapps[arch].RemoveAll()
        self.onglets.imagesapps_i[arch].RemoveAll()
        self.onglets.list_apps[arch].DeleteAllItems()
        self.onglets.list_ver_installed[arch].DeleteAllItems()

        root = self.onglets.list_apps[arch].AddRoot("")
        self.i = 0
        if(arch == "x86"):
            while(self.i < len(self.download32.versions)):
                self.onglets.imagesapps[arch].Add(wx.Bitmap(Variables.playonlinux_env+"/etc/install/wine-packages.png"))
                self.onglets.list_apps[arch].AppendItem(root,self.download32.versions[self.i],self.i)
                self.i += 1
        if(arch == "amd64"):
            while(self.i < len(self.download64.versions)):
                self.onglets.imagesapps[arch].Add(wx.Bitmap(Variables.playonlinux_env+"/etc/install/wine-packages.png"))
                self.onglets.list_apps[arch].AppendItem(root,self.download64.versions[self.i],self.i)
                self.i += 1

        root2 = self.onglets.list_ver_installed[arch].AddRoot("")
        wfolder = os_pref+"-"+arch

        installed_versions = os.listdir(Variables.playonlinux_rep+"/wine/"+wfolder)
        installed_versions.sort(key=keynat)
        installed_versions.reverse()
        self.i = 0
        self.j = 0
        while(self.i < len(installed_versions)):
            if(os.path.isdir(Variables.playonlinux_rep+"/wine/"+wfolder+"/"+installed_versions[self.i])):
                if(len(os.listdir(Variables.playonlinux_rep+"/wine/"+wfolder+"/"+installed_versions[self.i])) == 0):
                    self.onglets.imagesapps_i[arch].Add(wx.Bitmap(Variables.playonlinux_env+"/etc/install/wine-warning.png"))
                else:
                    self.onglets.imagesapps_i[arch].Add(wx.Bitmap(Variables.playonlinux_env+"/etc/install/wine.png"))
                self.onglets.list_ver_installed[arch].AppendItem(root2,installed_versions[self.i],self.j)
                self.j += 1
            self.i += 1
        try :
            if(versions[0] == "Wine packages website is unavailable"):
                self.onglets.list_apps[arch].Enable(False)
                self.onglets.imagesapps[arch].RemoveAll()
        except :
            pass
        self.onglets.button_rm[arch].Enable(False)
        self.onglets.button_in[arch].Enable(False)

    def closeapp(self, event):
        self.download32.thread_running = False
        if(os.environ["AMD64_COMPATIBLE"] == "True"):
            self.download64.thread_running = False

        self.Destroy()
